@@ -216,7 +216,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.2.43'
+__version__ = '0.3.43'
 
 
 register_package_translations()
@@ -234,7 +234,7 @@ TOUR_EXIT_DELAY_DEF = 0.45                                          #: default v
 IGNORED_HELP_FLOWS = (CLOSE_POPUP_FLOW_ID, )                        #: tuple of flow ids never search/show help text for
 IGNORED_HELP_STATES = ('flow_id', 'flow_path', 'win_rectangle')     #: tuple of app state names never searched help for
 
-REGISTERED_TOURS = dict()                                           #: map(name: class) of all registered tour classes
+REGISTERED_TOURS = {}                                               #: map(name: class) of all registered tour classes
 
 
 AnchorSpecType = Tuple[float, float, str]                           #: (see return value of :func:`anchor_spec`)
@@ -474,7 +474,7 @@ class TourBase:
         self._auto_switch_page_request = None
         self._delayed_setup_layout_call = None
         self._initial_page_data = None
-        self._saved_app_states: Dict[str, Any] = dict()
+        self._saved_app_states: Dict[str, Any] = {}
 
         self.auto_switch_pages: Union[bool, int] = False
         """ enable/disable automatic switch of tour pages.
@@ -489,7 +489,7 @@ class TourBase:
         """
 
         self.page_data: Dict[str, Any] = dict(
-            help_vars=dict(), tour_start_delay=TOUR_START_DELAY_DEF, tour_exit_delay=TOUR_EXIT_DELAY_DEF)
+            help_vars={}, tour_start_delay=TOUR_START_DELAY_DEF, tour_exit_delay=TOUR_EXIT_DELAY_DEF)
         """ additional/optional help variables (in `help_vars` key), tour and page text/layout/timing settings.
 
         the class attribute values are default values for all tour pages and get individually overwritten for each tour
@@ -511,7 +511,7 @@ class TourBase:
         * `tour_exit_delay`: seconds between tour.stop() and the on_tour_exit main app event (def=TOUR_EXIT_DELAY_DEF).
         """
 
-        self.pages_explained_matchers: Dict[str, Union[ExplainedMatcherType, Tuple[ExplainedMatcherType, ...]]] = dict()
+        self.pages_explained_matchers: Dict[str, Union[ExplainedMatcherType, Tuple[ExplainedMatcherType, ...]]] = {}
         """ matchers (specified as callable or id-string) to determine the explained widget(s) of each tour page.
 
         each key of this dict is a tour page id (for which the explained widget(s) will be determined).
@@ -528,7 +528,7 @@ class TourBase:
 
         """
 
-        self.page_ids: List[str] = list()
+        self.page_ids: List[str] = []
         """ list of tour page ids, either initialized via this class attribute or dynamically. """
 
         self.page_idx: int = 0                      #: index of the current tour page (in :attr:`.page_ids`)
@@ -566,7 +566,7 @@ class TourBase:
     @property
     def last_page_id(self) -> Optional[str]:
         """ determine last displayed tour page id. """
-        return None if self.last_page_idx is None else self.page_ids[self.last_page_idx]    # type: ignore # silly mypy
+        return None if self.last_page_idx is None else self.page_ids[self.last_page_idx]
 
     def load_page_data(self):
         """ load page before switching to it (and maybe reload after preparing app flow and before setup of layout). """
@@ -574,7 +574,7 @@ class TourBase:
         page_cnt = len(self.page_ids)
         assert 0 <= page_idx < page_cnt, f"page_idx ({page_idx}) has to be equal or greater zero and below {page_cnt}"
         page_id = self.page_ids[page_idx]
-        if self._initial_page_data is None:     # reset page data to tour class default: dict(help_vars=dict(), ...)
+        if self._initial_page_data is None:     # reset page data to tour class default: dict(help_vars={}, ...)
             self._initial_page_data = self.page_data
             page_data = deepcopy(self.page_data)
         else:
@@ -659,7 +659,7 @@ class TourBase:
         main_app = self.main_app
         layout: Any = self.layout
         exp_wid = main_app.help_activator       # fallback widget
-        widgets = list()
+        widgets = []
         page_id = self.page_ids[self.page_idx]
         if page_id in self.pages_explained_matchers:
             matchers = self.pages_explained_matchers[page_id]
@@ -674,7 +674,7 @@ class TourBase:
                     match_str = ""
                 wid = main_app.find_widget(matcher)
                 if not wid and match_str:
-                    wid = getattr(main_app.framework_root, 'ids', dict()).get(match_str)
+                    wid = getattr(main_app.framework_root, 'ids', {}).get(match_str)
                 if wid:
                     widgets.append(wid)
                 else:
@@ -1146,8 +1146,8 @@ class HelpAppBase(MainAppBase, ABC):
         :param _event_kwargs:   (unused)
         :return:                always True.
         """
-        if self.help_layout and self.help_widget(self.displayed_help_id, dict()) is self.help_activator:
-            self.help_display('', dict())
+        if self.help_layout and self.help_widget(self.displayed_help_id, {}) is self.help_activator:
+            self.help_display('', {})
         return True
 
     def save_app_states(self) -> str:
@@ -1187,7 +1187,7 @@ class HelpAppBase(MainAppBase, ABC):
         :param parent_widget:   parent widget to determine all children that are tourable.
         :return:                list of page ids of tourable children of the passed parent widget.
         """
-        tourable_children = list()
+        tourable_children = []
         for wid in self.widget_children(parent_widget, only_visible=True):
             page_id = widget_page_id(wid)
             if not page_id:
